@@ -2,22 +2,11 @@
 # under the Affero General Public License v3, see <https://www.gnu.org/licenses/>.
 
 
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    List,
-    NewType,
-    Optional,
-    Sequence,
-    Tuple,
-    TypeVar,
-    Union,
-    cast,
-)
+from typing import NewType, Sequence, Tuple, TypeVar, Union
 
 import numpy as np
 import torch
+from torch.nn import Module
 from torch.utils.tensorboard import SummaryWriter
 
 Array = Union[np.ndarray, torch.Tensor]
@@ -28,9 +17,16 @@ OneOrMore = Union[T, Sequence[T]]
 
 ScalarFloat = Union[torch.Tensor, float]
 
-# Define a `Writer` because otherwise, the documentation by mkdocs became very long and
+# Define alias types because otherwise, the documentation by mkdocs became very long and
 # made the website look ugly.
 TensorboardSummaryWriter = NewType("Writer", SummaryWriter)
+TorchModule = NewType("Module", Module)
 
-
-__all__ = ["Array", "Shape", "OneOrMore", "ScalarFloat", "TensorboardSummaryWriter"]
+__all__ = [
+    "Array",
+    "Shape",
+    "OneOrMore",
+    "ScalarFloat",
+    "TensorboardSummaryWriter",
+    "TorchModule",
+]
